@@ -4,7 +4,6 @@ logging utils
 import asyncio
 import logging
 import logging.config
-import sys
 import threading
 import traceback
 from datetime import datetime
@@ -106,4 +105,3 @@ class GRPCHandler(logging.Handler):
 
 grpcHandler = GRPCHandler()
 grpcHandler.add_custom_print_exception()
-sys.excepthook = grpcHandler.log_unhandled_exception
