@@ -1,6 +1,9 @@
 import io
+import json
 import logging
+import os
 
+import protoparser
 from django.apps import apps
 from django.contrib.postgres.fields import ArrayField
 from django.db import models
@@ -12,6 +15,8 @@ from django_socio_grpc.utils.model_extractor import get_model
 
 logger = logging.getLogger("django_socio_grpc")
 
+MAX_SORT_NUMBER = 99
+
 
 class ModelProtoGenerator:
     type_mapping = {
@@ -47,7 +52,7 @@ class ModelProtoGenerator:
         models.Field.__name__: "string",
     }
 
-    def __init__(self, project_name, app_name, model_name=None):
+    def __init__(self, project_name, app_name, model_name=None, existing_proto_path=None):
         self.model_name = model_name
         self.app_name = app_name
         self.project_name = project_name
@@ -61,8 +66,51 @@ class ModelProtoGenerator:
             # INFO - AM - 20/04/2021 - Can use tee method to duplicate the generator but I don't see the main goal here
             self.models = list(app.get_models())
 
+        self.existing_proto_data = self.parse_existing_proto_file(existing_proto_path)
+
         self._writer = _CodeWriter()
 
+    def check_if_existing_proto_file(self, existing_proto_path):
+        """
+        This method is here only to help mocking test because os.path.exists is call multiple time
+        """
+        return os.path.exists(existing_proto_path)
+
+    def parse_existing_proto_file(self, existing_proto_path):
+        if not self.check_if_existing_proto_file(existing_proto_path):
+            return None
+
+        proto_data = protoparser.serialize2json_from_file(existing_proto_path)
+
+        return json.loads(proto_data)
+
+    def find_existing_number_for_field(self, grpc_message_name, field_name):
+        """
+        Find if the field for this grpc message was already existing and return its number
+        """
+        if not self.existing_proto_data:
+            return MAX_SORT_NUMBER
+
+        if grpc_message_name not in self.existing_proto_data.get("messages", {}):
+            return MAX_SORT_NUMBER
+
+        if field_name.startswith("__custom__"):
+            _, field_name = self.get_custom_item_type_and_name(field_name)
+
+        for parsed_field in self.existing_proto_data["messages"][grpc_message_name]["fields"]:
+            if parsed_field["name"] == field_name:
+                return parsed_field["number"]
+
+        return MAX_SORT_NUMBER
+
+    def order_message_by_existing_number(self, grpc_message_name, grpc_message_fields_name):
+        grpc_message_fields_name.sort(
+            key=lambda field_name: self.find_existing_number_for_field(
+                grpc_message_name, field_name
+            )
+        )
+        return grpc_message_fields_name
+
     def get_proto(self):
         self._writer.write_line('syntax = "proto3";')
         self._writer.write_line("")
@@ -157,6 +205,9 @@ class ModelProtoGenerator:
         with self._writer.indent():
             number = 0
             # Info - AM - 30/04/2021 - Write all fields as defined in the meta of the model
+            grpc_message_fields_name = self.order_message_by_existing_number(
+                grpc_message_name, grpc_message_fields_name
+            )
             for field_name in grpc_message_fields_name:
                 number += 1
 
