@@ -329,3 +329,163 @@ message ImportStructEvenInArrayModel {
 }
 
 """
+
+
+SIMPLE_APP_MODEL_OLD_ORDER = """syntax = "proto3";
+
+package myproject.fakeapp;
+
+import "google/protobuf/empty.proto";
+
+service UnitTestModelController {
+    rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
+    rpc Create(UnitTestModel) returns (UnitTestModel) {}
+    rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
+    rpc Update(UnitTestModel) returns (UnitTestModel) {}
+    rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
+    rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
+}
+
+message UnitTestModel {
+    int32 id = 1;
+    string text = 2;
+}
+
+message UnitTestModelListRequest {
+}
+
+message UnitTestModelListResponse {
+    repeated UnitTestModel results = 1;
+    int32 count = 2;
+}
+
+message UnitTestModelRetrieveRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelDestroyRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelStreamRequest {
+}
+
+"""
+
+SIMPLE_APP_MODEL_GENERATED_FROM_OLD_ORDER = """syntax = "proto3";
+
+package myproject.fakeapp;
+
+import "google/protobuf/empty.proto";
+
+service UnitTestModelController {
+    rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
+    rpc Create(UnitTestModel) returns (UnitTestModel) {}
+    rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
+    rpc Update(UnitTestModel) returns (UnitTestModel) {}
+    rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
+    rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
+}
+
+message UnitTestModel {
+    int32 id = 1;
+    string text = 2;
+    string title = 3;
+}
+
+message UnitTestModelListRequest {
+}
+
+message UnitTestModelListResponse {
+    repeated UnitTestModel results = 1;
+    int32 count = 2;
+}
+
+message UnitTestModelRetrieveRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelDestroyRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelStreamRequest {
+}
+
+"""
+
+APP_MODEL_WITH_CUSTOM_FIELD_OLD_ORDER = """syntax = "proto3";
+
+package myproject.fakeapp;
+
+import "google/protobuf/empty.proto";
+
+service RelatedFieldModelController {
+    rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
+    rpc Create(RelatedFieldModel) returns (RelatedFieldModel) {}
+    rpc Retrieve(RelatedFieldModelRetrieveRequest) returns (RelatedFieldModel) {}
+    rpc Update(RelatedFieldModel) returns (RelatedFieldModel) {}
+    rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
+}
+
+message RelatedFieldModel {
+    string uuid = 1;
+}
+
+message RelatedFieldModelListRequest {
+}
+
+message RelatedFieldModelListResponse {
+    string uuid = 1;
+    string custom_field_name = 2;
+}
+
+message RelatedFieldModelRetrieveRequest {
+    string uuid = 1;
+}
+
+message RelatedFieldModelDestroyRequest {
+    string uuid = 1;
+}
+
+"""
+
+APP_MODEL_WITH_CUSTOM_FIELD_FROM_OLD_ORDER = """syntax = "proto3";
+
+package myproject.fakeapp;
+
+import "google/protobuf/empty.proto";
+
+service RelatedFieldModelController {
+    rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
+    rpc Create(RelatedFieldModel) returns (RelatedFieldModel) {}
+    rpc Retrieve(RelatedFieldModelRetrieveRequest) returns (RelatedFieldModel) {}
+    rpc Update(RelatedFieldModel) returns (RelatedFieldModel) {}
+    rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
+}
+
+message RelatedFieldModel {
+    string uuid = 1;
+    string foreign = 2;
+}
+
+message RelatedFieldModelListRequest {
+}
+
+message RelatedFieldModelListResponse {
+    string uuid = 1;
+    string custom_field_name = 2;
+    string foreign = 3;
+    repeated string many_many = 4;
+    repeated string list_custom_field_name = 5;
+}
+
+message RelatedFieldModelRetrieveRequest {
+    string uuid = 1;
+}
+
+message RelatedFieldModelDestroyRequest {
+    string uuid = 1;
+}
+
+"""
